==> syncope-3.0.14-source-release.zip: syncope-3.0.14/ext/oidcc4ui/persistence-jpa/src/main/java/org/apache/syncope/core/persistence/jpa/OIDCC4UIPersistenceContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.jpa;

import org.apache.syncope.core.persistence.api.dao.OIDCC4UIProviderDAO;
import org.apache.syncope.core.persistence.api.entity.OIDCC4UIEntityFactory;
import org.apache.syncope.core.persistence.jpa.dao.JPAOIDCC4UIProviderDAO;
import org.apache.syncope.core.persistence.jpa.entity.JPAOIDCC4UIEntityFactory;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration(proxyBeanMethods = false)
public class OIDCC4UIPersistenceContext {

    @ConditionalOnMissingBean
    @Bean
    public OIDCC4UIEntityFactory oidcc4UIEntityFactory() {
        return new JPAOIDCC4UIEntityFactory();
    }

    @ConditionalOnMissingBean
    @Bean
    public OIDCC4UIProviderDAO oidcc4UIProviderDAO() {
        return new JPAOIDCC4UIProviderDAO();
    }
}

==> syncope-4.0.1-source-release.zip: syncope-4.0.1/ext/oidcc4ui/persistence-jpa/src/main/java/org/apache/syncope/core/persistence/jpa/OIDCC4UIPersistenceContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.jpa;

import org.apache.syncope.core.persistence.api.dao.OIDCC4UIProviderDAO;
import org.apache.syncope.core.persistence.api.entity.OIDCC4UIEntityFactory;
import org.apache.syncope.core.persistence.jpa.dao.repo.OIDCC4UIProviderRepo;
import org.apache.syncope.core.persistence.jpa.entity.JPAOIDCC4UIEntityFactory;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.jpa.repository.support.JpaRepositoryFactory;

@Configuration(proxyBeanMethods = false)
public class OIDCC4UIPersistenceContext {

    @ConditionalOnMissingBean
    @Bean
    public OIDCC4UIEntityFactory oidcc4UIEntityFactory() {
        return new JPAOIDCC4UIEntityFactory();
    }

    @ConditionalOnMissingBean
    @Bean
    public OIDCC4UIProviderDAO oidcc4UIProviderDAO(final JpaRepositoryFactory jpaRepositoryFactory) {
        return jpaRepositoryFactory.getRepository(OIDCC4UIProviderRepo.class);
    }
}
